var hasCameraPermissions = Ti.Media.hasCameraPermissions();

if (OS_IOS) {
	var map = {};
	map[Ti.Media.CAMERA_AUTHORIZATION_AUTHORIZED] = 'CAMERA_AUTHORIZATION_AUTHORIZED';
	map[Ti.Media.CAMERA_AUTHORIZATION_DENIED] = 'CAMERA_AUTHORIZATION_DENIED';
	map[Ti.Media.CAMERA_AUTHORIZATION_RESTRICTED] = 'CAMERA_AUTHORIZATION_RESTRICTED';
	map[Ti.Media.CAMERA_AUTHORIZATION_NOT_DETERMINED] = 'CAMERA_AUTHORIZATION_NOT_DETERMINED';

	var cameraAuthorizationStatus = Ti.Media.cameraAuthorizationStatus;
	Ti.API.trace('Ti.Media.cameraAuthorizationStatus', 'Ti.Media.' + map[cameraAuthorizationStatus]);

	if (cameraAuthorizationStatus === Ti.Media.CAMERA_AUTHORIZATION_RESTRICTED) {

	} else if (cameraAuthorizationStatus === Ti.Media.CAMERA_AUTHORIZATION_DENIED) {
		dialogs.confirm({
			title : 'You denied the permissions before',
			message : 'Tap Yes to open the Settings App to grant permission there.',
		});
	}
}

var handleCamera = function() {
	Ti.API.trace("[index] >> [handleCamera]");
	var isIphoneX = OS_IOS ? Alloy.Globals.isIphoneX : false;

	//flag to check if user clicked the capture button so that we can disable it while image is being processes.
	//This is to stop the user from clicking multiple images.
	var imageClicked = false;

	//overlay to be set over camera
	var camera = Ti.UI.createView({
		height : Ti.UI.FILL,
		width : Ti.UI.FILL,
	});

	var captureButton = Ti.UI.createImageView({
		image : "captureIcon.png",
		height : "100dp",
		width : "100dp",
		bottom : "10dp",
	});

	captureButton.addEventListener('singletap', function() {
		if (!imageClicked) {
			imageClicked = true;
			Ti.Media.takePicture();
		} else {
			Ti.API.error("[index] >> image is processing. cannot capture inbetween.");
		}
	});

	camera.add(captureButton);

	var galleryIcon = Ti.UI.createImageView({
		image : "GalleryIcon.png",
		height : "40dp",
		width : "40dp",
		bottom : "30dp",
		left : "10%",
	});

	galleryIcon.addEventListener('singletap', function() {
		Ti.Media.hideCamera();
	});

	camera.add(galleryIcon);

	var crossButtonView = Ti.UI.createView({
		height : "80dp",
		width : "80dp",
		top : (isIphoneX) ? "35dp" : "20dp",
		right : (isIphoneX) ? "30dp" : "20dp"
	});

	var closeIcon = Ti.UI.createImageView({
		image : "cross.png",
		height : "30dp",
		width : "30dp"
	});

	crossButtonView.add(closeIcon);

	crossButtonView.addEventListener('singletap', function() {
		Ti.Media.hideCamera();
	});

	camera.add(crossButtonView);

	Titanium.Media.addEventListener('cameraready', function() {
		Ti.API.info("[index] >> camera ready event fired. Android 6+ device ?");
	});

	Titanium.Media.showCamera({
		success : function(event) {
			Ti.API.trace("[index] >> [showCamera]", event);
			imageClicked = false;
			transformImage(event.media, function(err, resp) {
				Ti.Media.hideCamera();
			});

		},
		cancel : function() {
			// called when user cancels taking a picture
			Ti.API.info("[customCamera] >> [closeClicked] >> Camera Canceled");
			imageClicked = false;
			Ti.Media.hideCamera();
		},
		error : function(error) {
			// called when there's an error
			imageClicked = false;
			Ti.Media.hideCamera();
			var alert = Titanium.UI.createAlertDialog({
				title : 'Camera'
			});
			if (error.code == Titanium.Media.NO_CAMERA) {
				alert.setMessage('Camera not supported.');
			} else {
				alert.setMessage('Unexpected error: ' + error.code);
			}
			alert.show();
		},
		autohide : false,
		showControls : false,
		overlay : camera,
		saveToPhotoGallery : true
	});

};

function transformImage(pathToImage, callback) {
	Ti.API.trace.trace("[index] >> [transformImage]");

	var platformHeight = Ti.Platform.displayCaps.platformWidth;
	var platformWidth = Ti.Platform.displayCaps.platformHeight;

	try {

		var length = pathToImage.length;
		var constant_length = 8000000;

		var ImageFactory = require('ti.imagefactory');

		if (platformWidth > platformHeight) {
			temp = platformWidth;
			platformWidth = platformHeight;
			platformHeight = temp;
		}

		platformHeight = (platformWidth * pathToImage.height) / pathToImage.width;

		newBlob = ImageFactory.imageAsResized(pathToImage, {
			width : platformWidth,
			height : platformHeight
		});

		if (OS_IOS) {
			if (newBlob.length > constant_length) {
				callback("File size is more than 8MB.", null);
			} else {
				callback(null, newBlob);
			}
		} else {
			var filename = Titanium.Filesystem.applicationDataDirectory + pathToImage.file.name;
			var f = Titanium.Filesystem.getFile(filename);
			f.write(newBlob);

			if (f.size > constant_length) {
				callback("File size is more than 8MB.", null);
			} else {
				callback(null, f);
			}
		}
	} catch(e) {
		callback("Unable to upload this image", null);
	}
}

$.index.open();